# Readers

Readers are what permits Fabricius to make advantages of 3rd-party project templating engines using Fabricius's objects.
Each readers define a "setup" functions that will be ran against certain defined parameters.

In the end, the "setup" function must return a "Template" object from Fabricius.
